"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const monaco_textmate_1 = require("monaco-textmate");
class TokenizerState {
    constructor(_ruleStack) {
        this._ruleStack = _ruleStack;
    }
    get ruleStack() {
        return this._ruleStack;
    }
    clone() {
        return new TokenizerState(this._ruleStack);
    }
    equals(other) {
        if (!other ||
            !(other instanceof TokenizerState) ||
            other !== this ||
            other._ruleStack !== this._ruleStack) {
            return false;
        }
        return true;
    }
}
/**
 * Wires up monaco-editor with monaco-textmate
 *
 * @param monaco monaco namespace this operation should apply to (usually the `monaco` global unless you have some other setup)
 * @param registry TmGrammar `Registry` this wiring should rely on to provide the grammars
 * @param languages `Map` of language ids (string) to TM names (string)
 */
function wireTmGrammars(monaco, registry, languages) {
    return Promise.all(Array.from(languages.keys())
        .map((languageId) => __awaiter(this, void 0, void 0, function* () {
        const grammar = yield registry.loadGrammar(languages.get(languageId));
        monaco.languages.setTokensProvider(languageId, {
            getInitialState: () => new TokenizerState(monaco_textmate_1.INITIAL),
            tokenize: (line, state) => {
                const res = grammar.tokenizeLine(line, state.ruleStack);
                return {
                    endState: new TokenizerState(res.ruleStack),
                    tokens: res.tokens.map(token => (Object.assign({}, token, { 
                        // TODO: At the moment, monaco-editor doesn't seem to accept array of scopes
                        scopes: token.scopes[token.scopes.length - 1] }))),
                };
            }
        });
    })));
}
exports.wireTmGrammars = wireTmGrammars;
//# sourceMappingURL=index.js.map